@@ -11,6 +11,17 @@ def get_bytes(string):
     return byte
 
 
+def bad_seed_checker(il, ir=False):
+    if ir:
+        parse_ir = str(il)
+        if not parse_ir:
+            raise ValueError("Bad seed, resulting in invalid key!")
+    else:
+        parse_il = int.from_bytes(il, "big")
+        if parse_il == 0:
+            raise ValueError("Bad seed, resulting in invalid key!")
+
+
 def prune_root_scalar(string):
     s = bytearray(get_bytes(string=string))
     s[0] = s[0] & 248
